import { ValidationState } from "./validation/ValidationState";
import { TileImplicitTiling } from "./structure/TileImplicitTiling";
import { ValidationResult } from "./validation/ValidationResult";
/**
 * A class summarizing the command-line functions of the validator.
 *
 * The functions in this class are supposed to be called from `main.ts`,
 * based on the parsed command line arguments.
 *
 * @internal
 */
export declare class ValidatorMain {
    static readonly specsDataRootDir = "specs/data/";
    static validateTilesetFile(fileName: string, reportFileName: string | undefined): Promise<ValidationResult>;
    static validateTilesetsDirectory(directoryName: string, globPattern: string, writeReports: boolean): Promise<void>;
    static validateSchemaFile(fileName: string, reportFileName: string | undefined): Promise<ValidationResult>;
    static validateSubtreeFile(fileName: string, validationState: ValidationState, implicitTiling: TileImplicitTiling | undefined, reportFileName: string | undefined): Promise<ValidationResult>;
    static validateAllTilesetSpecFiles(writeReports: boolean): Promise<void>;
    static validateAllMetadataSchemaSpecFiles(writeReports: boolean): Promise<void>;
    static validateAllSubtreeSpecFiles(writeReports: boolean): Promise<void>;
    static validateSubtreeSpecFile(fileName: string, reportFileName: string | undefined): Promise<void>;
    /**
     * Register the validators for known extensions
     */
    static registerExtensionValidators(): void;
    /**
     * Derives a file name for a report from the given input file name.
     * The resulting file name will be a file in the same directory as
     * the given one. Further details are intentionally not specified here.
     *
     * @param inputFileName - The input file name
     * @returns The report file name
     */
    static deriveReportFileName(inputFileName: string): string | undefined;
}
//# sourceMappingURL=ValidatorMain.d.ts.map