"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TilesetArchive3dtiles = void 0;
const defined_1 = require("./base/defined");
const better_sqlite3_1 = __importDefault(require("better-sqlite3"));
const TilesetArchiveError_1 = require("./TilesetArchiveError");
const Iterables_1 = require("./base/Iterables");
/**
 * Implementation of a TilesetArchive based on a 3DTILES (SQLITE3 database)
 * file.
 */
class TilesetArchive3dtiles {
    /**
     * Default constructor
     */
    constructor() {
        this.db = undefined;
    }
    open(fullInputName) {
        if ((0, defined_1.defined)(this.db)) {
            throw new TilesetArchiveError_1.TilesetArchiveError("Database already opened");
        }
        this.db = new better_sqlite3_1.default(fullInputName);
    }
    getKeys() {
        if (!(0, defined_1.defined)(this.db)) {
            throw new TilesetArchiveError_1.TilesetArchiveError("Archive is not opened. Call 'open' first.");
        }
        const selection = this.db.prepare("SELECT * FROM media");
        const iterator = selection.iterate();
        return Iterables_1.Iterables.map(iterator, (row) => row.key);
    }
    getEntry(key) {
        if (!(0, defined_1.defined)(this.db)) {
            throw new Error("Archive is not opened. Call 'open' first.");
        }
        const selection = this.db.prepare("SELECT * FROM media WHERE key = ?");
        const row = selection.get(key);
        if ((0, defined_1.defined)(row)) {
            return row.content;
        }
        return undefined;
    }
    close() {
        if (!(0, defined_1.defined)(this.db)) {
            throw new Error("Archive is not opened. Call 'open' first.");
        }
        this.db.close();
        this.db = undefined;
    }
}
exports.TilesetArchive3dtiles = TilesetArchive3dtiles;
