"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TilesetArchive3tz = void 0;
const defined_1 = require("./base/defined");
const fs_1 = __importDefault(require("fs"));
const TilesetArchiveError_1 = require("./TilesetArchiveError");
const ArchiveFunctions3tz_1 = require("./ArchiveFunctions3tz");
/**
 * Implementation of a TilesetArchive based on a 3TZ file.
 */
class TilesetArchive3tz {
    /**
     * Default constructor
     */
    constructor() {
        this.fd = undefined;
        this.zipIndex = undefined;
    }
    getZipIndex() {
        return this.zipIndex;
    }
    open(fullInputName) {
        if ((0, defined_1.defined)(this.fd)) {
            throw new TilesetArchiveError_1.TilesetArchiveError("Archive already opened");
        }
        this.fd = fs_1.default.openSync(fullInputName, "r");
        this.zipIndex = ArchiveFunctions3tz_1.ArchiveFunctions3tz.readZipIndex(this.fd);
    }
    getKeys() {
        if (!(0, defined_1.defined)(this.fd)) {
            throw new TilesetArchiveError_1.TilesetArchiveError("Archive is not opened. Call 'open' first.");
        }
        let index = 0;
        // eslint-disable-next-line @typescript-eslint/no-this-alias
        const that = this;
        return {
            [Symbol.iterator]() {
                return this;
            },
            next() {
                if (index >= that.zipIndex.length) {
                    return { value: undefined, done: true };
                }
                const entry = that.zipIndex[index];
                const offset = entry.offset;
                const fileName = ArchiveFunctions3tz_1.ArchiveFunctions3tz.readFileName(that.fd, offset);
                const result = {
                    value: fileName,
                    done: false,
                };
                index++;
                return result;
            },
        };
    }
    getEntry(key) {
        if (!(0, defined_1.defined)(this.fd)) {
            throw new TilesetArchiveError_1.TilesetArchiveError("Archive is not opened. Call 'open' first.");
        }
        const entryData = ArchiveFunctions3tz_1.ArchiveFunctions3tz.readEntryData(this.fd, this.zipIndex, key);
        return entryData;
    }
    close() {
        if (!(0, defined_1.defined)(this.fd)) {
            throw new TilesetArchiveError_1.TilesetArchiveError("Archive is not opened. Call 'open' first.");
        }
        fs_1.default.closeSync(this.fd);
        this.fd = undefined;
        this.zipIndex = undefined;
    }
}
exports.TilesetArchive3tz = TilesetArchive3tz;
