"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TilesetArchiveBuilder3dtiles = void 0;
const defined_1 = require("./base/defined");
const fs_1 = __importDefault(require("fs"));
const better_sqlite3_1 = __importDefault(require("better-sqlite3"));
const TilesetArchiveError_1 = require("./TilesetArchiveError");
/**
 * Implementation of a TilesetArchiveBuilder that creates a
 * 3DTILES (SQLITE3 database) file.
 */
class TilesetArchiveBuilder3dtiles {
    /**
     * Default constructor
     */
    constructor() {
        this.db = undefined;
    }
    begin(fullOutputName, overwrite) {
        if (fs_1.default.existsSync(fullOutputName)) {
            if (overwrite) {
                fs_1.default.unlinkSync(fullOutputName);
            }
            else {
                throw new TilesetArchiveError_1.TilesetArchiveError("File already exists: " + fullOutputName);
            }
        }
        if ((0, defined_1.defined)(this.db)) {
            throw new TilesetArchiveError_1.TilesetArchiveError("Archive already opened");
        }
        this.db = new better_sqlite3_1.default(fullOutputName);
        this.db.prepare("PRAGMA journal_mode=off;").run();
        this.db.prepare("BEGIN").run();
        this.db
            .prepare("CREATE TABLE media (key TEXT PRIMARY KEY, content BLOB)")
            .run();
    }
    addEntry(key, content) {
        if (!(0, defined_1.defined)(this.db)) {
            throw new TilesetArchiveError_1.TilesetArchiveError("Archive is not opened. Call 'begin' first.");
        }
        const insertion = this.db.prepare("INSERT INTO media VALUES (?, ?)");
        insertion.run(key, content);
    }
    async end() {
        if (!(0, defined_1.defined)(this.db)) {
            throw new TilesetArchiveError_1.TilesetArchiveError("Archive is not opened. Call 'begin' first.");
        }
        this.db.prepare("COMMIT").run();
        this.db.close();
        this.db = undefined;
    }
}
exports.TilesetArchiveBuilder3dtiles = TilesetArchiveBuilder3dtiles;
