"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TilesetArchiveBuilder3tz = void 0;
const defined_1 = require("./base/defined");
const fs_1 = __importDefault(require("fs"));
const archiver_1 = __importDefault(require("archiver"));
const IndexBuilder_1 = require("./IndexBuilder");
const TilesetArchiveError_1 = require("./TilesetArchiveError");
/**
 * Implementation of a TilesetArchiveBuilder that creates a
 * 3TZ file.
 */
class TilesetArchiveBuilder3tz {
    /**
     * Default constructor
     */
    constructor() {
        this.outputStream = undefined;
        this.archive = undefined;
        this.indexBuilder = new IndexBuilder_1.IndexBuilder();
    }
    begin(fullOutputName, overwrite) {
        if (fs_1.default.existsSync(fullOutputName)) {
            if (overwrite) {
                fs_1.default.unlinkSync(fullOutputName);
            }
            else {
                throw new TilesetArchiveError_1.TilesetArchiveError("File already exists: " + fullOutputName);
            }
        }
        if ((0, defined_1.defined)(this.archive)) {
            throw new TilesetArchiveError_1.TilesetArchiveError("Archive already opened");
        }
        this.outputStream = fs_1.default.createWriteStream(fullOutputName);
        this.archive = (0, archiver_1.default)("zip", {
            store: true,
        });
        this.archive.pipe(this.outputStream);
        // Logging and error handling for archiver:
        this.archive.on("warning", (error) => {
            throw new TilesetArchiveError_1.TilesetArchiveError(`${error}`);
        });
        this.archive.on("error", (error) => {
            throw new TilesetArchiveError_1.TilesetArchiveError(`${error}`);
        });
    }
    addEntry(key, content) {
        if (!(0, defined_1.defined)(this.archive)) {
            throw new TilesetArchiveError_1.TilesetArchiveError("Archive is not opened. Call 'begin' first.");
        }
        this.archive.append(content, { name: key });
        this.indexBuilder.addEntry(key, content.length);
    }
    async end() {
        if (!(0, defined_1.defined)(this.archive)) {
            throw new TilesetArchiveError_1.TilesetArchiveError("Archive is not opened. Call 'begin' first.");
        }
        // Create the index data, and add it as the LAST entry of the ZIP
        const indexData = this.indexBuilder.createBuffer();
        this.archive.append(indexData, { name: "@3dtilesIndex1@" });
        await this.archive.finalize();
        this.outputStream = undefined;
        this.archive = undefined;
    }
}
exports.TilesetArchiveBuilder3tz = TilesetArchiveBuilder3tz;
