"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.TilesetArchiveBuilderFs = void 0;
const defined_1 = require("./base/defined");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const TilesetArchiveError_1 = require("./TilesetArchiveError");
/**
 * Implementation of a TilesetArchiveBuilder that writes into
 * a directory of a file system
 */
class TilesetArchiveBuilderFs {
    /**
     * Default constructor
     */
    constructor() {
        this.fullOutputName = undefined;
        this.overwrite = false;
    }
    begin(fullOutputName, overwrite) {
        if ((0, defined_1.defined)(this.fullOutputName)) {
            throw new TilesetArchiveError_1.TilesetArchiveError("Archive already opened");
        }
        this.fullOutputName = fullOutputName;
        this.overwrite = overwrite;
        if (!fs_1.default.existsSync(fullOutputName)) {
            fs_1.default.mkdirSync(fullOutputName, { recursive: true });
        }
    }
    addEntry(key, content) {
        if (!(0, defined_1.defined)(this.fullOutputName)) {
            throw new TilesetArchiveError_1.TilesetArchiveError("Archive is not opened. Call 'begin' first.");
        }
        const fullOutputFileName = path_1.default.join(this.fullOutputName, key);
        if (fs_1.default.existsSync(fullOutputFileName)) {
            if (!this.overwrite) {
                throw new TilesetArchiveError_1.TilesetArchiveError("File already exists: " + fullOutputFileName);
            }
        }
        // TODO Check call:
        // TODO Need mkdirSync if sub-path does not exist?
        // TODO Need to unlink if file exists?
        fs_1.default.writeFileSync(fullOutputFileName, content);
    }
    async end() {
        if (!(0, defined_1.defined)(this.fullOutputName)) {
            throw new TilesetArchiveError_1.TilesetArchiveError("Archive is not opened. Call 'begin' first.");
        }
        this.fullOutputName = undefined;
        this.overwrite = false;
    }
}
exports.TilesetArchiveBuilderFs = TilesetArchiveBuilderFs;
