"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.shouldGzip = void 0;
const defined_1 = require("./base/defined");
const isGzipped_1 = require("./base/isGzipped");
const path_1 = __importDefault(require("path"));
/**
 * Returns whether the given file should be zipped when it is
 * added to an archive.
 *
 * If the file data is given, and it is already Gzipped, then
 * `false` is returned.
 *
 * Otherwise, the decision is solely made based on the extension
 * of the given file. The exact set of extensions for which this
 * function returns `true` is not specified.
 *
 * NOTE: The behavior of this function resembles the `isTile`
 * function of the original `3d-tiles-validator` tools. In
 * fact, in resembles both of the `isTile` functions.
 * I don't know what's the 'right' thing to do here either...
 *
 * @param file - The file
 * @param data - The optional file data
 * @returns Whether the file should be zipped
 */
function shouldGzip(file, data) {
    if ((0, defined_1.defined)(data)) {
        if ((0, isGzipped_1.isGzipped)(data)) {
            return false;
        }
    }
    const extension = path_1.default.extname(file);
    const extensions = [
        ".json",
        ".b3dm",
        ".i3dm",
        ".pnts",
        ".cmpt",
        ".vctr",
        ".gltf",
        ".glb",
    ];
    return extensions.includes(extension);
}
exports.shouldGzip = shouldGzip;
