"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NumericArrayPropertyModel = void 0;
const NumericBuffers_1 = require("./NumericBuffers");
const PropertyModels_1 = require("./PropertyModels");
const MetadataTypes_1 = require("../metadata/MetadataTypes");
/**
 * Implementation of a `PropertyModel` for numeric array types.
 *
 * This includes all types that have numeric component types,
 * i.e. the `SCALAR`, `VECn` and `MATn` types, and the
 * (binary, and therefore numeric) representation of `ENUM`.
 *
 * @internal
 */
class NumericArrayPropertyModel {
    constructor(type, valuesBuffer, componentType, arrayOffsetsBuffer, arrayOffsetType, count) {
        this._type = type;
        this._valuesBuffer = valuesBuffer;
        this._componentType = componentType;
        this._arrayOffsetsBuffer = arrayOffsetsBuffer;
        this._arrayOffsetType = arrayOffsetType;
        this._count = count;
    }
    getPropertyValue(index) {
        const type = this._type;
        const valuesBuffer = this._valuesBuffer;
        const componentType = this._componentType;
        const arrayOffsetsBuffer = this._arrayOffsetsBuffer;
        const arrayOffsetType = this._arrayOffsetType;
        const count = this._count;
        const componentCount = MetadataTypes_1.MetadataTypes.componentCountForType(type);
        const arraySlice = PropertyModels_1.PropertyModels.computeSlice(index, arrayOffsetsBuffer, arrayOffsetType, count);
        const arrayOffset = arraySlice.offset;
        const arrayLength = arraySlice.length;
        const result = new Array(arrayLength);
        for (let i = 0; i < arrayLength; i++) {
            const n = arrayOffset + i;
            let element = undefined;
            if (type === "SCALAR" || type === "ENUM") {
                element = NumericBuffers_1.NumericBuffers.getNumericFromBuffer(valuesBuffer, n, componentType);
            }
            else {
                element = NumericBuffers_1.NumericBuffers.getNumericArrayFromBuffer(valuesBuffer, n, componentCount, componentType);
            }
            result[i] = element;
        }
        return result;
    }
}
exports.NumericArrayPropertyModel = NumericArrayPropertyModel;
