/// <reference types="node" />
/**
 * Methods for extracting `number`- or `bigint` values or arrays thereof
 * from `Buffer` objects
 *
 * @internal
 */
export declare class NumericBuffers {
    /**
     * Obtains a single number or bigint from the given buffer,
     * at the given index, based on the given component type.
     *
     * @param buffer - The buffer
     * @param index - The index
     * @param componentType - The component type
     * @returns The number or bigint
     * @throws DeveloperError If the given `componentType` is not valid
     */
    static getNumericFromBuffer(buffer: Buffer, index: number, componentType: string): any;
    /**
     * Obtains an array of number or bigint values from the given buffer,
     * starting at the given index, based on the given component type.
     *
     * @param buffer - The buffer
     * @param index - The index
     * @param arrayLength - The length of the array, in number of elements
     * @param componentType - The component type
     * @returns The number or bigint array
     * @throws DeveloperError If the given `componentType` is not valid
     */
    static getNumericArrayFromBuffer(buffer: Buffer, index: number, arrayLength: number, componentType: string): any;
    /**
     * Obtains a typed array of number or bigint values from the given buffer,
     * starting at the given index, based on the given component type.
     *
     * @param buffer - The buffer
     * @param index - The index
     * @param arrayLength - The length of the array, in number of elements
     * @param componentType - The component type
     * @returns The number or bigint typed array
     * @throws DeveloperError If the given `componentType` is not valid
     */
    private static getTypedArrayFromBuffer;
    /**
     * Returns an array that contains the `number`- or `bigint` values
     * that are stored in the given buffer
     *
     * @param buffer - The buffer
     * @param componentType - The component type
     * @returns The number or bigint array
     * @throws DeveloperError If the given `componentType` is not valid
     */
    static getNumericBufferAsArray(buffer: Buffer, componentType: string): any;
}
//# sourceMappingURL=NumericBuffers.d.ts.map