/// <reference types="node" />
import { BinaryPropertyTable } from "./BinaryPropertyTable";
import { PropertyModel } from "./PropertyModel";
/**
 * Methods related to `PropertyModel` instances
 *
 * @internal
 */
export declare class PropertyModels {
    /**
     * Creates a `PropertyModel` for the specified property in
     * the given `BinaryPropertyTable`.
     *
     * This assumes that the input is structurally valid, as
     * determined with the `BinaryPropertyTableValidator`.
     *
     * This will determine the type of the property and access its
     * associated data (i.e. the required buffer views data) from
     * the given `BinaryPropertyTable`. For each type of property,
     * this will return a matching implementation of the
     * `PropertyModel` interface.
     *
     * @param binaryPropertyTable - The `BinaryPropertyTable`
     * @param propertyId - The property ID
     * @returns The `PropertyModel`
     */
    static createPropertyModel(binaryPropertyTable: BinaryPropertyTable, propertyId: string): PropertyModel;
    /**
     * Returns the 'slice' information that is given by an offsets
     * buffer or a fixed number.
     *
     * This returns `{ offset, length }` for the `arrayOffsets` or
     * `stringOffsets` of a property, for a given index.
     *
     * When the given `count` is defined, then the result will
     * just be `{ index * count, count }`.
     *
     * Otherwise, the result will be `{ offset, length }`, where `offset`
     * is the offset that is read from the given buffer at index `index`,
     * and `length` is `offset[index+1] - offset[index]`.
     *
     * @param index - The index
     * @param offsetsBuffer - The offsets
     * @param offsetType - The `componentType` for the offsets
     * @param count - The count
     * @returns The slice information
     */
    static computeSlice(index: number, offsetsBuffer: Buffer | undefined, offsetType: string, count: number | undefined): {
        offset: number;
        length: number;
    };
}
//# sourceMappingURL=PropertyModels.d.ts.map