import { BinaryPropertyTable } from "./BinaryPropertyTable";
import { PropertyModel } from "./PropertyModel";
import { ClassProperty } from "../structure/Metadata/ClassProperty";
import { MetadataEntityModel } from "../metadata/MetadataEntityModel";
import { PropertyTableProperty } from "../structure/PropertyTableProperty";
/**
 * Implementation of a model for a property table that is backed
 * by binary data.
 *
 * @internal
 */
export declare class PropertyTableModel {
    /**
     * The structure containing the raw data of the binary
     * property table
     */
    private readonly _binaryPropertyTable;
    /**
     * A mapping from property IDs to the `PropertyModel`
     * instances that provide the property values. These
     * are the "columns" of the table
     */
    private readonly _propertyIdToModel;
    /**
     * A mapping from 'semantic' strings to the 'propertyId'
     * strings of the properties that have the respective
     * semantic
     */
    private readonly _semanticToPropertyId;
    constructor(binaryPropertyTable: BinaryPropertyTable);
    /**
     * Returns the `MetadataEntityModel` that corresponds to the
     * row of the table with the given index.
     *
     * @param index - The index (i.e. the table row)
     * @returns The `MetdataEntityModel`
     * @throws MetadataError If the index is out of range
     */
    getMetadataEntityModel(index: number): MetadataEntityModel;
    /**
     * Returns the `ClassProperty` that defines the structure of the
     * property with the given ID, or `undefined` if this table was
     * created for a `MetadataClass` that does not define this property.
     *
     * @param propertyId - The property ID
     * @returns The `ClassProperty`
     */
    getClassProperty(propertyId: string): ClassProperty | undefined;
    /**
     * Returns the `PropertyTableProperty` that defines the structure of the
     * property with the given ID, or `undefined` if this table was
     * created for a `PropertyTable` that does not define this property.
     *
     * @param propertyId - The property ID
     * @returns The `PropertyTableProperty`
     */
    getPropertyTableProperty(propertyId: string): PropertyTableProperty | undefined;
    /**
     * Returns the `PropertyModel` for the property with the given ID.
     * This is the "column" of the table that contains the property
     * data. Returns `undefined` if this table was created for
     * a `MetadataClass` that does not define this property.
     *
     * @param propertyId - The property ID
     * @returns The `PropertyModel`
     */
    getPropertyModel(propertyId: string): PropertyModel | undefined;
}
//# sourceMappingURL=PropertyTableModel.d.ts.map