"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StringPropertyModel = void 0;
const ArrayBuffers_1 = require("./ArrayBuffers");
const PropertyModels_1 = require("./PropertyModels");
/**
 * Implementation of a `PropertyModel` for strings
 *
 * @internal
 */
class StringPropertyModel {
    constructor(valuesBuffer, stringOffsetsBuffer, stringOffsetType) {
        this._valuesBuffer = valuesBuffer;
        this._stringOffsetsBuffer = stringOffsetsBuffer;
        this._stringOffsetType = stringOffsetType;
    }
    getPropertyValue(index) {
        const valuesBuffer = this._valuesBuffer;
        const stringOffsetsBuffer = this._stringOffsetsBuffer;
        const stringOffsetType = this._stringOffsetType;
        const stringSlice = PropertyModels_1.PropertyModels.computeSlice(index, stringOffsetsBuffer, stringOffsetType, undefined);
        const stringOffset = stringSlice.offset;
        const stringLength = stringSlice.length;
        const arrayBuffer = ArrayBuffers_1.ArrayBuffers.fromBuffer(valuesBuffer);
        const result = StringPropertyModel.decoder.decode(arrayBuffer.slice(stringOffset, stringOffset + stringLength));
        return result;
    }
}
exports.StringPropertyModel = StringPropertyModel;
StringPropertyModel.decoder = new TextDecoder();
