/// <reference types="node" />
import { AvailabilityInfo } from "./AvailabilityInfo";
import { Availability } from "../structure/Availability";
import { TileImplicitTiling } from "../structure/TileImplicitTiling";
/**
 * Methods for creating `AvailabilityInfo` instances
 *
 * @internal
 */
export declare class AvailabilityInfos {
    /**
     * Creates a new `AvailabilityInfo` for the given availability
     * information, for tile- or content availability.
     *
     * @param availability - The `Availability` object
     * @param bufferViewDatas - The `BufferView` data chunks
     * @param implicitTiling - The `TileImplicitTiling` object
     * @returns The `AvailabilityInfo` object
     * @throws ImplicitTilingError If the given data is structurally
     * invalid.
     */
    static createTileOrContent(availability: Availability, bufferViewDatas: Buffer[], implicitTiling: TileImplicitTiling): AvailabilityInfo;
    /**
     * Creates a new `AvailabilityInfo` for the given availability
     * information, for child subtree availability
     *
     * @param availability - The `Availability` object
     * @param bufferViewDatas - The `BufferView` data chunks
     * @param implicitTiling - The `TileImplicitTiling` object
     * @returns The `AvailabilityInfo` object
     * @throws ImplicitTilingError If the given data is structurally
     * invalid.
     */
    static createChildSubtree(availability: Availability, bufferViewDatas: Buffer[], implicitTiling: TileImplicitTiling): AvailabilityInfo;
    /**
     * Creates a new `AvailabilityInfo` for the given availability
     * information, for child subtree availability
     *
     * @param availability - The `Availability` object
     * @param bufferViewDatas - The `BufferView` data chunks
     * @param length - The length of the availability info
     * @returns The `AvailabilityInfo` object
     */
    private static create;
}
//# sourceMappingURL=AvailabilityInfos.d.ts.map