"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OctreeCoordinates = void 0;
const MortonOrder_1 = require("./MortonOrder");
const Octrees_1 = require("./Octrees");
/**
 * An implementation of `TreeCoordinates` for octrees
 */
class OctreeCoordinates {
    constructor(level, x, y, z) {
        this.toString = () => {
            return `(level ${this.level}, (${this._x},${this._y},${this._z}))`;
        };
        this._level = level;
        this._x = x;
        this._y = y;
        this._z = z;
    }
    get level() {
        return this._level;
    }
    get x() {
        return this._x;
    }
    get y() {
        return this._y;
    }
    get z() {
        return this._z;
    }
    parent() {
        if (this._level === 0) {
            return null;
        }
        const pLevel = this._level - 1;
        const px = this._x >> 1;
        const py = this._y >> 1;
        const pz = this._z >> 1;
        return new OctreeCoordinates(pLevel, px, py, pz);
    }
    *children() {
        const nLevel = this._level + 1;
        const nX = this._x << 1;
        const nY = this._y << 1;
        const nZ = this._z << 1;
        yield new OctreeCoordinates(nLevel, nX + 0, nY + 0, nZ + 0);
        yield new OctreeCoordinates(nLevel, nX + 1, nY + 0, nZ + 0);
        yield new OctreeCoordinates(nLevel, nX + 0, nY + 1, nZ + 0);
        yield new OctreeCoordinates(nLevel, nX + 1, nY + 1, nZ + 0);
        yield new OctreeCoordinates(nLevel, nX + 0, nY + 0, nZ + 1);
        yield new OctreeCoordinates(nLevel, nX + 1, nY + 0, nZ + 1);
        yield new OctreeCoordinates(nLevel, nX + 0, nY + 1, nZ + 1);
        yield new OctreeCoordinates(nLevel, nX + 1, nY + 1, nZ + 1);
    }
    descendants(maxLevelInclusive, 
    // eslint-disable-next-line @typescript-eslint/no-inferrable-types
    depthFirst = false) {
        const queue = [this];
        const result = {
            [Symbol.iterator]() {
                return this;
            },
            next() {
                const element = depthFirst ? queue.pop() : queue.shift();
                if (!element) {
                    return { value: undefined, done: true };
                }
                if (element.level < maxLevelInclusive) {
                    for (const c of element.children()) {
                        queue.push(c);
                    }
                }
                return { value: element, done: false };
            },
        };
        return result;
    }
    toArray() {
        return [this.level, this.x, this.y, this.z];
    }
    toIndex() {
        const offset = Octrees_1.Octrees.computeNumberOfNodesForLevels(this._level);
        return offset + this.toIndexInLevel();
    }
    toIndexInLevel() {
        return MortonOrder_1.MortonOrder.encode3D(this._x, this._y, this._z);
    }
}
exports.OctreeCoordinates = OctreeCoordinates;
