/// <reference types="node" />
import { SubtreeInfo } from "./SubtreeInfo";
import { ResourceResolver } from "../io/ResourceResolver";
import { Subtree } from "../structure/Subtree";
import { TileImplicitTiling } from "../structure/TileImplicitTiling";
/**
 * Methods to create `SubtreeInfo` instances.
 */
export declare class SubtreeInfos {
    /**
     * Creates a new `SubtreeInfo` from the given binary subtree data.
     *
     * This method assumes that the given binary data is consistent
     * and valid. This can be checked with the `SubtreeValidator`
     * class.
     *
     * @param input - The whole buffer of a binary subtree file
     * @param implicitTiling - The `TileImplicitTiling` that
     * defines the expected structure of the subtree data
     * @param resourceResolver - The `ResourceResolver` that
     * will be used to resolve buffer URIs
     * @returns A promise with the `SubtreeInfo`
     * @throws An ImplicitTilingError when the subtree JSON could
     * not be parsed, or there was a buffer without a URI
     * and no binary buffer was given, or one of the requested
     * buffers could not be resolved.
     */
    static createFromBuffer(input: Buffer, implicitTiling: TileImplicitTiling, resourceResolver: ResourceResolver): Promise<SubtreeInfo>;
    /**
     * Creates a new `SubtreeInfo` from the given `Subtree` object
     * and the (optional) binary buffer.
     *
     * This method assumes that the given data is consistent
     * and valid. This can be checked with the `SubtreeValidator`
     * class.
     *
     * @param subtree - The `Subtree` object
     * @param binaryBuffer - The optional binary buffer
     * @param implicitTiling - The `TileImplicitTiling` that
     * defines the expected structure of the subtree data
     * @param resourceResolver - The `ResourceResolver` that
     * will be used to resolve buffer URIs
     * @returns A promise with the `SubtreeInfo`
     * @throws A ImplicitTilingError when there was a buffer without
     * a URI and no binary buffer was given, or the requested buffer
     * data could not be resolved.
     */
    static create(subtree: Subtree, binaryBuffer: Buffer | undefined, implicitTiling: TileImplicitTiling, resourceResolver: ResourceResolver): Promise<SubtreeInfo>;
}
//# sourceMappingURL=SubtreeInfos.d.ts.map