"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ArchiveResourceResolver = void 0;
const path_1 = __importDefault(require("path"));
const Uris_1 = require("./Uris");
const defined_1 = require("../base/defined");
/**
 * Implementation of a `ResourceResolver` based on a `TilesetArchive`
 *
 * @internal (Instantiated by the `ResourceResolvers` class)
 */
class ArchiveResourceResolver {
    constructor(basePath, archiveFileName, archive) {
        this._basePath = basePath;
        this._archiveFileName = archiveFileName;
        this._archive = archive;
    }
    resolveUri(uri) {
        const resolved = path_1.default.resolve(this._basePath, decodeURIComponent(uri));
        return resolved;
    }
    async resolveData(uri) {
        if (Uris_1.Uris.isDataUri(uri)) {
            const data = Buffer.from(uri.split(",")[1], "base64");
            return data;
        }
        if (Uris_1.Uris.isAbsoluteUri(uri)) {
            return null;
        }
        let archiveUri = path_1.default.join(this._basePath, uri);
        archiveUri = archiveUri.replace(/\\/g, "/");
        const entry = this._archive.getEntry(archiveUri);
        // TODO Log message for experiment:
        /*/
        console.log(
          "Resolving " +
            uri +
            " resolved to  " +
            archiveUri +
            " from archive " +
            this._archiveFileName +
            " returns " +
            (defined(entry) ? entry.length + " bytes" : "undefined")
        );
        //*/
        if (!(0, defined_1.defined)(entry)) {
            return null;
        }
        return entry;
    }
    async resolveDataPartial(uri, 
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    maxBytes) {
        return await this.resolveData(uri);
    }
    derive(uri) {
        let resolved = path_1.default.join(this._basePath, decodeURIComponent(uri));
        resolved = resolved.replace(/\\/g, "/");
        const result = new ArchiveResourceResolver(resolved, this._archiveFileName, this._archive);
        return result;
    }
}
exports.ArchiveResourceResolver = ArchiveResourceResolver;
