"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileResourceResolver = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const Uris_1 = require("./Uris");
/**
 * Implementation of a `ResourceResolver` based on a file system.
 *
 * @internal (Instantiated by the `ResourceResolvers` class)
 */
class FileResourceResolver {
    constructor(basePath) {
        this._basePath = basePath;
    }
    resolveUri(uri) {
        let resolved = path_1.default.resolve(this._basePath, decodeURIComponent(uri));
        resolved = resolved.replace(/\\/g, "/");
        return resolved;
    }
    async resolveDataPartial(uri, maxBytes) {
        if (Uris_1.Uris.isDataUri(uri)) {
            const data = Buffer.from(uri.split(",")[1], "base64");
            return data;
        }
        if (Uris_1.Uris.isAbsoluteUri(uri)) {
            return null;
        }
        const resolved = this.resolveUri(uri);
        try {
            const buffer = Buffer.alloc(maxBytes);
            const fd = fs_1.default.openSync(resolved, "r");
            fs_1.default.readSync(fd, buffer, 0, maxBytes, 0);
            fs_1.default.closeSync(fd);
            return buffer;
        }
        catch (error) {
            return null;
        }
    }
    async resolveData(uri) {
        if (Uris_1.Uris.isDataUri(uri)) {
            const data = Buffer.from(uri.split(",")[1], "base64");
            return data;
        }
        if (Uris_1.Uris.isAbsoluteUri(uri)) {
            return null;
        }
        const resolved = this.resolveUri(uri);
        // Using `readFileSync` directly causes a buffer to be returned
        // that will appear to contain garbage data when it is used by
        // the glTF-Validator. If anybody could explain to me why this
        // does not work, that would be great.
        //return fs.readFileSync(resolved);
        //*/
        // eslint-disable-next-line @typescript-eslint/no-unused-vars
        return new Promise((resolve, reject) => {
            fs_1.default.readFile(resolved, (err, data) => {
                if (err) {
                    resolve(null);
                }
                else {
                    resolve(data);
                }
            });
        });
        //*/
    }
    derive(uri) {
        const resolved = path_1.default.join(this._basePath, decodeURIComponent(uri));
        return new FileResourceResolver(resolved);
    }
}
exports.FileResourceResolver = FileResourceResolver;
