"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ResourceResolvers = void 0;
const FileResourceResolver_1 = require("./FileResourceResolver");
const UnzippingResourceResolver_1 = require("./UnzippingResourceResolver");
/**
 * Methods to create `ResourceResolver` instances.
 */
class ResourceResolvers {
    /**
     * Creates a new `ResourceResolver` that resolves resources from
     * the file system, relative to the given directory.
     *
     * The returned instance will transparently unpack ZIPped data.
     *
     * @param directory - The base directory
     * @returns The `ResourceResolver`
     */
    static createFileResourceResolver(directory) {
        const delegate = new FileResourceResolver_1.FileResourceResolver(directory);
        return ResourceResolvers.wrapUnzipping(delegate);
    }
    /**
     * Wraps the given `ResourceResolver` into one that unzips the data
     * from the given delegate, if that that is ZIPped.
     *
     * @param resourceResolver - The delegate
     * @returns The unzipping `ResourceResolver`
     */
    static wrapUnzipping(resourceResolver) {
        return new UnzippingResourceResolver_1.UnzippingResourceResolver(resourceResolver);
    }
}
exports.ResourceResolvers = ResourceResolvers;
