"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.StructureValidationIssues = void 0;
const ValidationIssue_1 = require("../validation/ValidationIssue");
const ValidationIssueSeverity_1 = require("../validation/ValidationIssueSeverity");
/**
 * Methods to create `ValidationIssue` instances that describe
 * generic, structural errors.
 */
class StructureValidationIssues {
    /**
     * Indicates that a certain identifier was not found as
     * a key in a dictionary.
     *
     * @param path - The path for the `ValidationIssue`
     * @param message - The message for the `ValidationIssue`
     * @returns The `ValidationIssue`
     */
    static IDENTIFIER_NOT_FOUND(path, message) {
        const type = "IDENTIFIER_NOT_FOUND";
        const severity = ValidationIssueSeverity_1.ValidationIssueSeverity.ERROR;
        const issue = new ValidationIssue_1.ValidationIssue(type, path, message, severity);
        return issue;
    }
    /**
     * Indicates that a value that is required based on the presence
     * or absence of another value has not been defined.
     *
     * @param path - The path for the `ValidationIssue`
     * @param message - The message for the `ValidationIssue`
     * @returns The `ValidationIssue`
     */
    static REQUIRED_VALUE_NOT_FOUND(path, message) {
        const type = "REQUIRED_VALUE_NOT_FOUND";
        const severity = ValidationIssueSeverity_1.ValidationIssueSeverity.ERROR;
        const issue = new ValidationIssue_1.ValidationIssue(type, path, message, severity);
        return issue;
    }
}
exports.StructureValidationIssues = StructureValidationIssues;
