/**
 * Internal utility methods for validation issues
 *
 * @internal
 */
export declare class ValidationIssueUtils {
    /**
     * Creates a short string with a verbal description of the
     * given range. This requires at least one of the given
     * arguments to be defined.
     *
     * @param min - The minimum
     * @param max - The maximum
     * @returns The description
     */
    static describeSimpleRange(min: number | undefined, max: number | undefined): string;
    /**
     * Joins the given strings, enclosed in single quotes,
     * using commas and the given conjunction ("and" or "or").
     *
     * Examples:
     *
     * undefined : undefined
     * [] : ""
     * ["a"] : "'a'"
     * ["a", "b"] : "'a' and 'b'"
     * ["a", "b", "c"] : "'a', 'b', and 'c'"
     *
     * @param conjunction - The conjunction to use
     * @param s - The strings
     * @returns The joined names
     */
    static joinNames(conjunction: string, ...s: string[]): string | undefined;
}
//# sourceMappingURL=ValidationIssueUtils.d.ts.map