"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidationIssues = void 0;
const ValidationIssue_1 = require("../validation/ValidationIssue");
const ValidationIssueSeverity_1 = require("../validation/ValidationIssueSeverity");
/**
 * Methods to create generic `ValidationIssue` instances
 */
class ValidationIssues {
    /**
     * An issue that describes an internal error in the validator.
     * Clients should usually not receive this issue. It is used
     * as a last resort to gracefully handle internal issues
     * without breaking the validation process.
     *
     * @param path - The path for the `ValidationIssue`
     * @param message - The message for the `ValidationIssue`
     * @returns The `ValidationIssue`
     */
    static INTERNAL_ERROR(path, message) {
        const type = "INTERNAL_ERROR";
        const severity = ValidationIssueSeverity_1.ValidationIssueSeverity.ERROR;
        const issue = new ValidationIssue_1.ValidationIssue(type, path, message, severity);
        return issue;
    }
}
exports.ValidationIssues = ValidationIssues;
