/**
 * Internal utilities related to the `type` of the
 * `ClassProperty` instances of `MetadataClass` objects
 *
 * @internal
 */
export declare class MetadataTypes {
    /**
     * The valid values for the `class.property.type` property
     */
    static allTypes: string[];
    /**
     * The valid values for the `class.property.type` property
     * that count as "numeric" types. These are the ones where
     * a `class.property.componentType` is given
     */
    static numericTypes: string[];
    /**
     * Returns whether the given type is numeric, i.e. whether
     * it is SCALAR, VECn, or MATn.
     *
     * @param type - The type
     * @returns Whether the type is numeric
     */
    static isNumericType(type: string): boolean;
    /**
     * Returns the number of components for the given type
     *
     * @param type - The type
     * @returns The number of components
     * @throws DeveloperError If the given string is not one
     * of the types contained in `allTypes`
     */
    static componentCountForType(type: string): number;
}
//# sourceMappingURL=MetadataTypes.d.ts.map