import { BinaryEnumInfo } from "../binary/BinaryEnumInfo";
import { Schema } from "../structure/Metadata/Schema";
import { ClassProperty } from "../structure/Metadata/ClassProperty";
/**
 * Internal utilities related to metadata
 *
 * @internal
 */
export declare class MetadataUtilities {
    /**
     * Computes the `BianaryEnumInfo` that summarizes information
     * about the binary representation of `MetadataEnum` values
     * from the given schema.
     *
     * @param schema - The metadata `Schema`
     * @returns The `BinaryEnumInfo`
     */
    static computeBinaryEnumInfo(schema: Schema): BinaryEnumInfo;
    /**
     * Computes a mapping from enum type names to the `valueType` that
     * the respective `MetdataEnum` has (defaulting to `UINT16` if it
     * did not define one)
     *
     * @param schema - The metadata `Schema`
     * @returns The mapping from enum type names to enum value types
     */
    private static computeEnumValueTypes;
    /**
     * Computes a mapping from enum type names to the dictionaries
     * that map the enum values names to the enum value values.
     *
     * @param schema - The metadata `Schema`
     * @returns The mapping from enum type names to dictionaries
     */
    private static computeEnumValueNameValues;
    /**
     * Internal method to obtain the names of enum values for the
     * given property.
     *
     * This tries to return the list of all
     * `schema.enums[classProperty.enumType].values[i].name`
     * values, returning the empty list the property does not have an
     * enum type or any element is not defined.
     *
     * @param classProperty - The `ClassProperty`
     * @param schema - The `Schema`
     * @returns The enum value names
     */
    static obtainEnumValueNames(classProperty: ClassProperty, schema: Schema): string[];
}
//# sourceMappingURL=MetadataUtilities.d.ts.map