import { TraversedTile } from "./TraversedTile";
import { Tile } from "../structure/Tile";
import { Content } from "../structure/Content";
import { ResourceResolver } from "../io/ResourceResolver";
import { Schema } from "../structure/Metadata/Schema";
import { TileImplicitTiling } from "../structure/TileImplicitTiling";
import { MetadataEntity } from "../structure/MetadataEntity";
/**
 * An implementation of a `TraversedTile` that reflects a tile
 * that actually appears as a JSON representation in the tileset.
 */
export declare class ExplicitTraversedTile implements TraversedTile {
    /**
     * The parent tile, or `undefined` if this is the root
     */
    private readonly _parent;
    /**
     * The `Tile` object that this traversed tile was created for
     */
    private readonly _tile;
    /**
     * A JSON-path like path identifying this tile
     */
    private readonly _path;
    /**
     * The global level. This is the level starting at the
     * root of the tileset.
     */
    private readonly _level;
    /**
     * The metadata schema in the context of which this tile
     * is created. This is the schema that was obtained from
     * the `tileset.schema` or `tileset.schemaUri`. If this
     * is defined, it is assumed to be valid. If it is
     * undefined and a tile with metadata is encountered,
     * then an error will be thrown in `asTile`.
     */
    private readonly _schema;
    /**
     * The `ResourceResolver` that will resolve resources
     * that may be required if this is the root of an
     * implicit tileset (e.g. the subtree files).
     */
    private readonly _resourceResolver;
    constructor(tile: Tile, path: string, level: number, parent: TraversedTile | undefined, schema: Schema | undefined, resourceResolver: ResourceResolver);
    asTile(): Tile;
    get path(): string;
    get level(): number;
    getParent(): TraversedTile | undefined;
    getChildren(): Promise<TraversedTile[]>;
    getContents(): Content[];
    getSubtreeUri(): string | undefined;
    getImplicitTiling(): TileImplicitTiling | undefined;
    getMetadata(): MetadataEntity | undefined;
    toString: () => string;
}
//# sourceMappingURL=ExplicitTraversedTile.d.ts.map