import { TraversalCallback } from "./TraversalCallback";
import { ResourceResolver } from "../io/ResourceResolver";
import { Tileset } from "../structure/Tileset";
import { Schema } from "../structure/Metadata/Schema";
/**
 * A class that can traverse the tiles of a tileset.
 */
export declare class TilesetTraverser {
    /**
     * Traverses the tiles in the given tileset.
     *
     * This will traverse the tiles of the given tileset, starting
     * at the root. It will pass all tiles to the given callback,
     * as `TraversedTile` instances.
     *
     * @param tileset - The `Tileset`
     * @param schema - The schema from the `tileset.schema` or the
     * `tileset.schemaUri`. If this is defined, then it is assumed
     * to be a valid schema definition.
     * @param resourceResolver - The `ResourceResolver` that is used to
     * resolve resources for implicit tilesets (subtree files)
     * @param traversalCallback - The `TraversalCallback`
     * @param depthFirst - Whether the traversal should be depth-first
     * @returns A Promise that resolves when the traversal finished
     */
    static traverse(tileset: Tileset, schema: Schema | undefined, resourceResolver: ResourceResolver, traversalCallback: TraversalCallback, depthFirst?: boolean): Promise<void>;
}
//# sourceMappingURL=TilesetTraverser.d.ts.map