/// <reference types="node" />
import { ResourceResolver } from "../io/ResourceResolver";
/**
 * A class summarizing information about content data.
 *
 * This is only used in the `ContentDataValidator` and
 * `ContentDataValidators` classes, to facilitate the
 * lookup up validators for given content data, based
 * on criteria like the file extension or magic header.
 *
 * @internal
 */
export declare class ContentData {
    private readonly _uri;
    private readonly _extension;
    private readonly _resourceResolver;
    private _magic;
    private _data;
    private _dataWasRequested;
    constructor(uri: string, resourceResolver: ResourceResolver);
    get uri(): string;
    /**
     * Returns the extension of the file/URI from which
     * the buffer data was read, in lowercase, including
     * the `.` dot.
     */
    get extension(): string;
    /**
     * Returns a string that consists of the first 4 bytes
     * of the buffer data (or fewer, if the buffer contains
     * less than 4 bytes)
     */
    getMagic(): Promise<string>;
    getData(): Promise<Buffer | null>;
}
//# sourceMappingURL=ContentData.d.ts.map