import { ValidationContext } from "./ValidationContext";
import { ValidationState } from "./ValidationState";
import { Content } from "../structure/Content";
/**
 * A class for validations related to `content` objects.
 *
 * @internal
 */
export declare class ContentValidator {
    /**
     * Performs the validation to ensure that the given object is a
     * valid `content` object.
     *
     * This only performs the basic JSON-level and consistency checks.
     * It does not validate the content data that is referred to by the
     * `content.uri`. The validation of the content data is done with
     * `validateContentData`, if and only if this method returned `true`.
     *
     * @param contentPath - The path for the `ValidationIssue` instances
     * @param content - The object to validate
     * @param validationState - The `ValidationState`
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the given object was valid
     */
    static validateContent(contentPath: string, content: Content, validationState: ValidationState, context: ValidationContext): Promise<boolean>;
}
//# sourceMappingURL=ContentValidator.d.ts.map