import { ValidationContext } from "./ValidationContext";
import { RootProperty } from "../structure/RootProperty";
/**
 * A class for validations related to `rootProperty` objects.
 * This is the "base class" of the schema definitions that
 * nearly all schemas of the 3D Tiles specification refer to,
 * and which defines the `extensions` and `extras` properties.
 *
 * @internal
 */
export declare class RootPropertyValidator {
    /**
     * Performs the validation to ensure that the given object is a
     * valid `rootProperty` object.
     *
     * This will add all extension names that are found to the
     * given validation context.
     *
     * @param path - The path for `ValidationIssue` instances
     * @param name - The name of the object
     * @param rootProperty - The object to validate
     * @param context - The `ValidationContext` that any issues will be added to
     * @returns Whether the object was valid
     */
    static validateRootProperty(path: string, name: string, rootProperty: RootProperty, context: ValidationContext): boolean;
}
//# sourceMappingURL=RootPropertyValidator.d.ts.map