"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidationIssueFilters = void 0;
/**
 * Methods related to `ValidationIssueFilter` instances.
 *
 * @beta
 */
class ValidationIssueFilters {
    /**
     * Creates a `ValidationIssueFilter` that excludes all
     * `ValidationIssue` instances where the `ValidationIssue#type`
     * is one of the given strings.
     *
     * @param excludedTypes - The excluded type strings
     * @returns The `ValidationIssueFilter`
     */
    static byExcludedTypes(...excludedTypes) {
        const predicate = (issues) => !excludedTypes.includes(issues[issues.length - 1].type);
        return predicate;
    }
    /**
     * Creates a `ValidationIssueFilter` that includes all
     * `ValidationIssue` instances where the `ValidationIssue#severity`
     * is one of the given severities.
     *
     * @param includedServerities - The included severities
     * @returns The `ValidationIssueFilter`
     */
    static byIncludedSeverities(...includedServerities) {
        const predicate = (issues) => includedServerities.includes(issues[issues.length - 1].severity);
        return predicate;
    }
}
exports.ValidationIssueFilters = ValidationIssueFilters;
